==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderRFC2136Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderRFC2136Builder extends ACMEIssuerDNS01ProviderRFC2136FluentImpl<ACMEIssuerDNS01ProviderRFC2136Builder> implements VisitableBuilder<ACMEIssuerDNS01ProviderRFC2136,ACMEIssuerDNS01ProviderRFC2136Builder>{
  public ACMEIssuerDNS01ProviderRFC2136Builder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderRFC2136(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderRFC2136(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent,ACMEIssuerDNS01ProviderRFC2136 instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent,ACMEIssuerDNS01ProviderRFC2136 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withNameserver(instance.getNameserver());
      fluent.withTsigAlgorithm(instance.getTsigAlgorithm());
      fluent.withTsigKeyName(instance.getTsigKeyName());
      fluent.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136 instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136 instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withNameserver(instance.getNameserver());
      this.withTsigAlgorithm(instance.getTsigAlgorithm());
      this.withTsigKeyName(instance.getTsigKeyName());
      this.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderRFC2136 build() {
    ACMEIssuerDNS01ProviderRFC2136 buildable = new ACMEIssuerDNS01ProviderRFC2136(fluent.getNameserver(),fluent.getTsigAlgorithm(),fluent.getTsigKeyName(),fluent.getTsigSecretSecretRef());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderRFC2136Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderRFC2136Builder extends ACMEIssuerDNS01ProviderRFC2136Fluent<ACMEIssuerDNS01ProviderRFC2136Builder> implements VisitableBuilder<ACMEIssuerDNS01ProviderRFC2136,ACMEIssuerDNS01ProviderRFC2136Builder>{
  public ACMEIssuerDNS01ProviderRFC2136Builder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderRFC2136(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderRFC2136(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent,ACMEIssuerDNS01ProviderRFC2136 instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent,ACMEIssuerDNS01ProviderRFC2136 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderRFC2136());

    if (instance != null) {
      fluent.withNameserver(instance.getNameserver());
      fluent.withTsigAlgorithm(instance.getTsigAlgorithm());
      fluent.withTsigKeyName(instance.getTsigKeyName());
      fluent.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
      fluent.withNameserver(instance.getNameserver());
      fluent.withTsigAlgorithm(instance.getTsigAlgorithm());
      fluent.withTsigKeyName(instance.getTsigKeyName());
      fluent.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136 instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderRFC2136Builder(ACMEIssuerDNS01ProviderRFC2136 instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderRFC2136());

    if (instance != null) {
      this.withNameserver(instance.getNameserver());
      this.withTsigAlgorithm(instance.getTsigAlgorithm());
      this.withTsigKeyName(instance.getTsigKeyName());
      this.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
      this.withNameserver(instance.getNameserver());
      this.withTsigAlgorithm(instance.getTsigAlgorithm());
      this.withTsigKeyName(instance.getTsigKeyName());
      this.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderRFC2136Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderRFC2136 build() {
    ACMEIssuerDNS01ProviderRFC2136 buildable = new ACMEIssuerDNS01ProviderRFC2136(fluent.getNameserver(),fluent.getTsigAlgorithm(),fluent.getTsigKeyName(),fluent.buildTsigSecretSecretRef());
    return buildable;
  }
  
}
